<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Benutzer-Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administration</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Einen neuen Benutzer hinzufügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Benutzerkonto hinzufügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Passwort des neuen Benutzers noch einmal eintragen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>Passwort bestätigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <source>Username of new user</source>
        <translation>Benutzername des neuen Benutzers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>User login name:</source>
        <translation>Login-Name des Benutzers:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <location filename="../mainwindow.ui" line="416"/>
        <location filename="../mainwindow.ui" line="1134"/>
        <source>Enter username of new user</source>
        <translation>Benutzernamen des neuen Benutzers eintragen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="422"/>
        <source>username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Password for new user</source>
        <translation>Passwort für den neuen Benutzer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>User password:</source>
        <translation>Benutzerpasswort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Enter password for new user</source>
        <translation>Passwort für den neuen Benutzer eintragen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Confirm user password:</source>
        <translation>Benutzerpasswort bestätigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Delete User Account</source>
        <translation>Benutzerkonto löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Select user</source>
        <translation>Benutzer wählen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.ui" line="1222"/>
        <location filename="../mainwindow.ui" line="1346"/>
        <location filename="../mainwindow.ui" line="1368"/>
        <source>Select user to delete</source>
        <translation>Benutzerkonto auswählen, das gelöscht werden soll</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>User to delete:</source>
        <translation>Benutzer zu löschen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Home-Verzeichnis des Benutzers auch löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Delete user home directory</source>
        <translation>Home-Verzeichnis des Benutzers löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Rename User Account</source>
        <translation>Benutzerkonto umbenennen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to modify:</source>
        <translation>Benutzer auswählen, der geändert werden soll:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>New user name:</source>
        <translation>Neuer Benutzername: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Change User Password</source>
        <translation>Benutzerpasswort ändern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>new password</source>
        <translation>Neues Passwort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Confirm new password:</source>
        <translation>Neues Passwort bestätigen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>confirm new password</source>
        <translation>Neues Passwort bestätigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>New user password:</source>
        <translation>Neues Benutzerpasswort:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Repair a user configuration</source>
        <translation>Benutzerkonfiguration reparieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Modify User Account</source>
        <translation>Benutzerkonto ändern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Select user to repair</source>
        <translation>Auswählen des Benutzerkontos, das repariert werden soll</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <location filename="../mainwindow.ui" line="1355"/>
        <source>User to change:</source>
        <translation>Benutzerkonto zum Ändern:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="624"/>
        <source>Restore Defaults</source>
        <translation>Voreinstellungen wiederherstellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Browser-Einstellungen gemäss MX-Voreinstellungen wiederherstellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="651"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Mozilla (Iceweasel or Firefox)  Konfiguration</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Gruppenzugehörigkeiten gemäss MX Voreinstellungen wiederherstellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Group memberships</source>
        <translation>Gruppenzugehörigkeiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Change Autologin Settings</source>
        <translation>Ändere Autologin-Einstellungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Log in automatically</source>
        <translation>Automatische Anmeldung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Require password to log in</source>
        <translation>Ein Passwort bei der Anmeldung fordern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy/Sync</source>
        <translation>Kopieren/Synchronisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Copy Between Desktops</source>
        <translation>Kopieren zwischen Desktops</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <location filename="../mainwindow.ui" line="829"/>
        <source>Select desktop to copy from</source>
        <translation>Wählen Sie den Desktop, von dem aus kopiert werden soll</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>Select to only copy files</source>
        <translation>Auswahl: nur Dateien kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Copy only</source>
        <translation>Nur Kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Select desktop to copy to</source>
        <translation>Wählen Sie den Desktop, auf den kopiert werden soll</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <source>Copy to:</source>
        <translation>Kopieren auf:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Copy from:</source>
        <translation>Kopieren von:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>Select to copy and then delete differences</source>
        <translation>Wählen Sie kopieren und dann die Unterschiede löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="854"/>
        <source>Sync</source>
        <translation>Synchronisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select to copy/sync Shared</source>
        <translation>Gemeinsame Ordner kopieren /synchronisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="903"/>
        <source>Shared folder</source>
        <translation>Gemeinsamer Ordner</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Select to copy/sync entire home</source>
        <translation>Gesamtes Home-Verzeichnis kopieren / synchronisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Entire home</source>
        <translation>Gesamtes Home-Verzeichnis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="935"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Wählen, um die Browser-Konfiguration zu kopieren/synchronisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="938"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Mozilla (Firefox oder Iceweasel)  Konfiguration</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="951"/>
        <source>Select to copy/sync Documents</source>
        <translation>Dokumente kopieren/synchronisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Documents folder</source>
        <translation>Dokumente-Ordner</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="961"/>
        <source>What to copy/sync:</source>
        <translation>Was soll kopiert/synchronisiert werden:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="977"/>
        <source>Progress</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1007"/>
        <location filename="../mainwindow.ui" line="1023"/>
        <source>Status of the changes</source>
        <translation>Status der Änderungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1026"/>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1042"/>
        <source>Progress of the changes</source>
        <translation>Verlauf der Änderungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1079"/>
        <source>Add/Remove Groups</source>
        <translation>Gruppen hinzufügen/löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1091"/>
        <source>Add Group</source>
        <translation>Gruppe hinzufügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1121"/>
        <source>Group name:</source>
        <translation>Gruppenname:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>groupname</source>
        <translation>Gruppenname</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1169"/>
        <source>Delete Group</source>
        <translation>Gruppe löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1231"/>
        <source>Group to delete:</source>
        <translation>Gruppe zum Löschen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Group Membership</source>
        <translation>Gruppenzugehörigkeit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1375"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Gruppenzugehörigkeit des Benutzers (Gruppzugehörigkeit ändern, indem die entsprechenden Kästchen markiert werden oder nicht):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1395"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation>*Prüfen Sie bitte nochmals Ihre Auswahl, bevor Sie weiterfahren, falsche Gruppenzugehörigkeiten können das System zerstören.  Wenn Sie einen Fehler machen, benutzen Sie die Reparieren-Funktion um die ursprünglichen Gruppenzugehörigkeiten wiederherzustellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Apply any changes</source>
        <translation>Alle Änderungen akzeptieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Cancel any changes then quit</source>
        <translation>Änderungen zurückziehen und dann den Vorgang beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1475"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1526"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1533"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1540"/>
        <source>About this application</source>
        <translation>Infos zu diesem Programm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1543"/>
        <source>About...</source>
        <translation>Impressum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1550"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="109"/>
        <location filename="../mainwindow.cpp" line="141"/>
        <location filename="../mainwindow.cpp" line="149"/>
        <location filename="../mainwindow.cpp" line="162"/>
        <location filename="../mainwindow.cpp" line="173"/>
        <location filename="../mainwindow.cpp" line="182"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="651"/>
        <location filename="../mainwindow.cpp" line="682"/>
        <location filename="../mainwindow.cpp" line="691"/>
        <location filename="../mainwindow.cpp" line="836"/>
        <location filename="../mainwindow.cpp" line="949"/>
        <source>none</source>
        <translation>keine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Die Benutzer-Konfiguration wird repariert werden. Schliessen Sie jetzt bitte alle anderen Anwendungen. Anschliessend bitte ausloggen oder neu starten.  Sind Sie sicher, dass Sie jetzt reparieren wollen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="225"/>
        <source>User group membership was restored.</source>
        <translation>Die Mitgliedschaft bei der Nutzergruppe wurde wiederhergestellt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>Mozilla settings were reset.</source>
        <translation>Die Einstellungen für Mozilla wurden zurückgesetzt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>Autologin options</source>
        <translation>Autologin-Optionen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Autologin ausgeschaltet für den Benutzer &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Autologin eingeschaltet für den Benutzer &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Ein Ziel für das &apos;Kopieren zu&apos; muss angegeben werden.  Es ist nicht möglich, den Desktop auf dem Sie eingelogt sind zu kopieren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Schliessen Sie alle andere Programme, bevor Sie kopieren.  Stellen Sie sicher, dass das Ziel genügend Platz bietet, um die zu kopierenden Dateien aufzunehmen.  Das Kopieren zwischen Desktops kann Dateien oder Einstellungen des Ziel-Desktops überschreiben oder zerstören.  Sind Sie sicher, dass Sie weiterfahren wollen? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Synchronizing desktop...</source>
        <translation>Der Desktop wird synchronisiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Copying desktop...</source>
        <translation>Der Desktop wird kopiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <location filename="../mainwindow.cpp" line="518"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Der Benutzername muss mindestens 2 Zeichen enthalten.  Wählen Sie bitte einen längeren Benutzernamen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Der Benutzername muss klein geschrieben werden und 
darf keine Sonderzeichen oder Leerzeichen enthalten.
Bitte wählen Sie einen anderen Namen, bevor Sie weiterfahren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Dieser Name ist bereits vergeben. Bitte einen anderen Namen wählen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="341"/>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Die eingetragenen Passwörter gleichen sich nicht.  Versuchen Sie es bitte noch einmal.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <location filename="../mainwindow.cpp" line="381"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Das Benutzer-Passwort muss mindestens 2 Zeichen lang sein. Bitte wählen Sie ein längeres Passwort, bevor Sie weitermachen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>The user was added ok.</source>
        <translation>Der Benutzer ist erfolgreich hinzugefügt worden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>Failed to add the user.</source>
        <translation>Der Benutzer konnte nicht hinzugefügt werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Password successfully changed.</source>
        <translation>Passwort erfolgreich geändert.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>Failed to change password.</source>
        <translation>Änderung des Passworts fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="405"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Diese Aktion kann nicht widerrufen werden.  Sind Sie sicher, dass Sie den Benutzer %1 löschen wollen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="418"/>
        <source>The user has been deleted.</source>
        <translation>Der Benutzer ist gelöscht worden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Failed to delete the user.</source>
        <translation>Der Benutzer konnte nicht gelöscht werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Der Gruppenname muss mindestens 2 Zeichen enthalten.  Wählen Sie bitte einen längeren Namen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="439"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Der Gruppename muss klein geschrieben werden und 
darf keine Sonderzeichen oder Leerzeichen enthalten.
Bitte wählen Sie einen anderen Namen, bevor Sie weiterfahren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Dieser Gruppenname ist bereits vergeben. Bitte einen anderen Namen für diese Gruppe wählen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="455"/>
        <source>The system group was added ok.</source>
        <translation>Die Systemgruppe ist erfolgreich hinzugefügt worden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>Failed to add the system group.</source>
        <translation>Die Systemgruppe konnte nicht hinzugefügt werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Diese Aktion kann nicht widerrufen werden.  Sind Sie sicher, dass Sie die Gruppe %1 löschen wollen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>The group has been deleted.</source>
        <translation>Die Gruppe ist gelöscht worden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>Failed to delete the group.</source>
        <translation>Die Gruppe konnte nicht gelöscht werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>The changes have been applied.</source>
        <translation>Die Änderungen wurden durchgeführt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>Failed to apply group changes</source>
        <translation>Die Änderungen an der Gruppe konnten nicht ausgeführt werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="509"/>
        <source>The selected user name is currently in use.</source>
        <translation>Der angegebene Benutzername wird gerade schon verwendet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Um diesen Benutzer umzubenennen bitte ausloggen und mit einem anderen Benutzerkonto wieder einloggen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Dieser Name existiert bereits auf dem System. Bitte einen anderen Namen wählen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Umbenennen des Benutzers fehlgeschlagen. Bitte stellen Sie sicher, daß dieser Benutzer nicht eingeloggt ist. Eventuell ist auch ein Neustart des Rechners nötig.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>The user was renamed.</source>
        <translation>Der Benutzer ist jetzt umbenannt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <location filename="../mainwindow.cpp" line="602"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Der Desktop wird synchronisiert...   Erfolgreich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="575"/>
        <location filename="../mainwindow.cpp" line="604"/>
        <source>Copying desktop...ok</source>
        <translation>Der Desktop wird kopiert...  Erfolgreich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="608"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Der Desktop wird synchronisiert...nicht gelungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="610"/>
        <source>Copying desktop...failed</source>
        <translation>Der Desktop wird kopiert...nicht gelungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="628"/>
        <location filename="../mainwindow.cpp" line="888"/>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>browse...</source>
        <translation>Durchsuchen...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="799"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="800"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="801"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Einfache Benutzer-Konfiguration für MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="803"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="804"/>
        <source>%1 License</source>
        <translation>%1 Lizenz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="819"/>
        <source>%1 Help</source>
        <translation>%1 Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="889"/>
        <source>Select folder to copy to</source>
        <translation>Zielordner für Kopie auswählen</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Close</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Dieses Programm muss als Benutzer &quot;root&quot; ausgeführt werden.</translation>
    </message>
</context>
</TS>
